pub type DataSlice<'a> = Slice<'a, AttributeValueVTable>;Expand description
A slice of attribute values belonging to a particular attribute.
Aliased Type
pub struct DataSlice<'a> { /* private fields */ }pub type DataSlice<'a> = Slice<'a, AttributeValueVTable>;A slice of attribute values belonging to a particular attribute.
pub struct DataSlice<'a> { /* private fields */ }