pub type DataSliceMut<'a> = SliceMut<'a, AttributeValueVTable>;Expand description
A mutable slice of attribute values belonging to a particular attribute.
Aliased Type
pub struct DataSliceMut<'a> { /* private fields */ }pub type DataSliceMut<'a> = SliceMut<'a, AttributeValueVTable>;A mutable slice of attribute values belonging to a particular attribute.
pub struct DataSliceMut<'a> { /* private fields */ }