pub type RangeExtent = [RangeInclusive<i32>; 3];Expand description
An extent for structured data specified as a triplet of inclusive ranges.
For example [ x0..=x1, y0..=y1, z0..=z1 ] gives the extent of a data set between x0 and
x1 in the x dimension and similar for y and z.